==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/CLOSINGCODEHIERARCHYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CLOSINGCODEHIERARCHYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CLOSINGCODEHIERARCHYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARENTCLOSINGCODEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CHILDCLOSINGCODEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CLOSINGCODEHIERARCHYID_Type", propOrder = {
    "parentclosingcodeid",
    "childclosingcodeid"
})
public class CLOSINGCODEHIERARCHYID_Type {

    @XmlElement(name = "PARENTCLOSINGCODEID", required = true)
    protected CLOSINGCODE_Type parentclosingcodeid;
    @XmlElement(name = "CHILDCLOSINGCODEID", required = true)
    protected CLOSINGCODE_Type childclosingcodeid;

    /**
     * Obtient la valeur de la propriété parentclosingcodeid.
     * 
     * @return
     *     possible object is
     *     {@link CLOSINGCODE_Type }
     *     
     */
    public CLOSINGCODE_Type getPARENTCLOSINGCODEID() {
        return parentclosingcodeid;
    }

    /**
     * Définit la valeur de la propriété parentclosingcodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLOSINGCODE_Type }
     *     
     */
    public void setPARENTCLOSINGCODEID(CLOSINGCODE_Type value) {
        this.parentclosingcodeid = value;
    }

    /**
     * Obtient la valeur de la propriété childclosingcodeid.
     * 
     * @return
     *     possible object is
     *     {@link CLOSINGCODE_Type }
     *     
     */
    public CLOSINGCODE_Type getCHILDCLOSINGCODEID() {
        return childclosingcodeid;
    }

    /**
     * Définit la valeur de la propriété childclosingcodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLOSINGCODE_Type }
     *     
     */
    public void setCHILDCLOSINGCODEID(CLOSINGCODE_Type value) {
        this.childclosingcodeid = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/CLOSINGCODEHIERARCHYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CLOSINGCODEHIERARCHYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CLOSINGCODEHIERARCHYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARENTCLOSINGCODEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CHILDCLOSINGCODEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CLOSINGCODEHIERARCHYID_Type", propOrder = {
    "parentclosingcodeid",
    "childclosingcodeid"
})
public class CLOSINGCODEHIERARCHYID_Type {

    @XmlElement(name = "PARENTCLOSINGCODEID", required = true)
    protected CLOSINGCODE_Type parentclosingcodeid;
    @XmlElement(name = "CHILDCLOSINGCODEID", required = true)
    protected CLOSINGCODE_Type childclosingcodeid;

    /**
     * Gets the value of the parentclosingcodeid property.
     * 
     * @return
     *     possible object is
     *     {@link CLOSINGCODE_Type }
     *     
     */
    public CLOSINGCODE_Type getPARENTCLOSINGCODEID() {
        return parentclosingcodeid;
    }

    /**
     * Sets the value of the parentclosingcodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLOSINGCODE_Type }
     *     
     */
    public void setPARENTCLOSINGCODEID(CLOSINGCODE_Type value) {
        this.parentclosingcodeid = value;
    }

    /**
     * Gets the value of the childclosingcodeid property.
     * 
     * @return
     *     possible object is
     *     {@link CLOSINGCODE_Type }
     *     
     */
    public CLOSINGCODE_Type getCHILDCLOSINGCODEID() {
        return childclosingcodeid;
    }

    /**
     * Sets the value of the childclosingcodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLOSINGCODE_Type }
     *     
     */
    public void setCHILDCLOSINGCODEID(CLOSINGCODE_Type value) {
        this.childclosingcodeid = value;
    }

}
